@@ -18,33 +18,19 @@ function setKeybinding(name, func) {
 }
 
 function enable() {
-    injections['_initialSelection'] = AltTab.WindowSwitcherPopup.prototype._initialSelection;
-    AltTab.WindowSwitcherPopup.prototype._initialSelection = function(backward, binding) {
-        if (binding == 'switch-windows-backward' ||
-            binding == 'switch-applications-backward' ||
-            binding == 'switch-group-backward' || backward)
-            this._select(this._items.length - 1);
-        else if (this._items.length == 1)
-            this._select(0);
-        else
-            this._select(1);
-    };
     injections['_keyPressHandler'] = AltTab.WindowSwitcherPopup.prototype._keyPressHandler;
     AltTab.WindowSwitcherPopup.prototype._keyPressHandler = function(keysym, action) {
-        if (action == Meta.KeyBindingAction.SWITCH_WINDOWS ||
-            action == Meta.KeyBindingAction.SWITCH_APPLICATIONS ||
-            action == Meta.KeyBindingAction.SWITCH_GROUP) {
-            this._select(this._next());
-        } else if (action == Meta.KeyBindingAction.SWITCH_WINDOWS_BACKWARD ||
-                   action == Meta.KeyBindingAction.SWITCH_APPLICATIONS_BACKWARD ||
-                   action == Meta.KeyBindingAction.SWITCH_GROUP_BACKWARD) {
-            this._select(this._previous());
-        } else {
-            if (keysym == Clutter.Left)
-                this._select(this._previous());
-            else if (keysym == Clutter.Right)
-                this._select(this._next());
+        switch(action) {
+            case Meta.KeyBindingAction.SWITCH_APPLICATIONS:
+            case Meta.KeyBindingAction.SWITCH_GROUP:
+              action = Meta.KeyBindingAction.SWITCH_WINDOWS;
+              break;
+            case Meta.KeyBindingAction.SWITCH_APPLICATIONS_BACKWARD:
+            case Meta.KeyBindingAction.SWITCH_GROUP_BACKWARD:
+              action = Meta.KeyBindingAction.SWITCH_WINDOWS_BACKWARD;
+              break;
         }
+        return injections['_keyPressHandler'].call(this, keysym, action);
     };
 
     setKeybinding('switch-applications', Lang.bind(Main.wm, Main.wm._startWindowSwitcher));
